@@ -1,5 +1,5 @@
 package App::XML::DocBook::Builder;
-$App::XML::DocBook::Builder::VERSION = '0.0700';
+$App::XML::DocBook::Builder::VERSION = '0.0800';
 use warnings;
 use strict;
 
@@ -48,13 +48,9 @@ __END__
 
 =encoding UTF-8
 
-=head1 NAME
-
-App::XML::DocBook::Builder
-
 =head1 VERSION
 
-version 0.0700
+version 0.0800
 
 =head1 SYNOPSIS
 
@@ -66,10 +62,6 @@ version 0.0700
 
 App::XML::DocBook::Builder - Build DocBook/XML files.
 
-=head1 VERSION
-
-version 0.0700
-
 =head1 FUNCTIONS
 
 =head2 initialize_makefiles($args)
@@ -128,7 +120,7 @@ This program is released under the following license: MIT/X11
 
 L<http://www.opensource.org/licenses/mit-license.php>
 
-=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+=for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 SUPPORT
 
@@ -165,14 +157,6 @@ L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-XML-DocBook-Builder>
 
 =item *
 
-AnnoCPAN
-
-The AnnoCPAN is a website that allows community annotations of Perl module documentation.
-
-L<http://annocpan.org/dist/App-XML-DocBook-Builder>
-
-=item *
-
 CPAN Ratings
 
 The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
